@@ -86,6 +86,9 @@ void AccessibilityManager::sync(const QString &key, const QVariant &value)
     {
         m_interface->call(key, value);
     }
+#else
+    Q_UNUSED(key)
+    Q_UNUSED(value)
 #endif
 }
 
